==> webgui_7.9.18.orig.tar.gz: WebGUI/lib/WebGUI/i18n/Spanish/Asset_WeatherData.pm <==
package WebGUI::i18n::Spanish::Asset_WeatherData;
use utf8;
our $I18N = {
  'Current Weather Conditions Template to use' => {
    'lastUpdated' => 1227127052,
    'message' => 'Plantilla para Condiciones de Clima'
  },
  'Default Locations' => {
    'lastUpdated' => 1227127081,
    'message' => 'Localidad(es)'
  },
  'Template' => {
    'lastUpdated' => 1227127106,
    'message' => 'Plantilla'
  },
  'WeatherData template title' => {
    'lastUpdated' => 1227127140,
    'message' => 'Plantilla para Estado del Tiempo'
  },
  'Your list of default weather locations' => {
    'lastUpdated' => 1227127253,
    'message' => '<p>Lista de localidades cuyo estado del tiempo quiere consultar, una por l&iacute;nea. Puede escribir (las dos primeras solamente son validades dentro de USA):</p><p>Ciudad, ST</p><p>C&oacute;digo Postal USA</p><p>Ciudad, Pa&iacute;s</p>'
  },
  'assetName' => {
    'lastUpdated' => 1227127155,
    'message' => 'Estado del Tiempo'
  },
  'cityState' => {
    'lastUpdated' => 1227127294,
    'message' => 'La ciudad y el estado retornados por NOAA. Probablemente sea id&eacute;ntico a query.'
  },
  'iconUrl' => {
    'lastUpdated' => 1227127319,
    'message' => 'URL a un &iacute;cono que representa la condici&oacute;n del cielo.'
  },
  'licenseKey' => {
    'lastUpdated' => 1227127343,
    'message' => 'Clave de Licencia para Weather.com'
  },
  'licenseKey help' => {
    'lastUpdated' => 1227127398,
    'message' => 'Ingrese la clave recibida por correo electr&oacute;nico despu&eacute;s de registrarse en el Servicio XML de Weather.com para consultar el Estado del Tiempo.'
  },
  'locations' => {
    'lastUpdated' => 1227127423,
    'message' => 'La lista de localidades especificadas por el usuario.'
  },
  'ourLocations.loop' => {
    'lastUpdated' => 1227127473,
    'message' => 'Un bucle que contiene la informaci&oacute;n del Estado del Tiempo de todas las localidades indicadas por el usuario.'
  },
  'partnerId' => {
    'lastUpdated' => 1227127512,
    'message' => 'Partner ID suministrado por Weather.com'
  },
  'partnerId help' => {
    'lastUpdated' => 1227127551,
    'message' => 'Ingrese el Parter ID recibido por correo electr&oacute;nico despu&eacute;s de registrarse en el Servicio XML de Estado del Tiempo de Weather.com.'
  },
  'query' => {
    'lastUpdated' => 1227127575,
    'message' => 'La localidad espec&iacute;fica.'
  },
  'sky' => {
    'lastUpdated' => 1227127603,
    'message' => 'Condici&oacute;n del cielo (soleado, nublado, etc.)'
  },
  'tempF' => {
    'lastUpdated' => 1227127620,
    'message' => 'Temperatura en grados Fahrenheit.'
  },
  'templateId' => {
    'lastUpdated' => 1227127641,
    'message' => 'ID de la Plantilla utilizada para presentar este Activo.'
  },
  'weatherdata asset template variables title' => {
    'lastUpdated' => 1227127661,
    'message' => 'Variables de Plantilla para Estado del Tiempo'
  },
  'you need a weather.com key' => {
    'lastUpdated' => 1227127736,
    'message' => 'Haga click aqu&iacute; para registrarse en el servicio gratuito Weather XML Data Feed the Weather.com, necesario para poder utilizar este activo.'
  }
}
;

1;

==> webgui_7.10.28.orig.tar.gz: WebGUI/lib/WebGUI/i18n/Spanish/Asset_WeatherData.pm <==
package WebGUI::i18n::Spanish::Asset_WeatherData;
use utf8;
our $I18N = {
  'Current Weather Conditions Template to use' => {
    'lastUpdated' => '1227127052',
    'message' => 'Plantilla para Condiciones de Clima'
  },
  'Default Locations' => {
    'lastUpdated' => '1227127081',
    'message' => 'Localidad(es)'
  },
  'Template' => {
    'lastUpdated' => '1227127106',
    'message' => 'Plantilla'
  },
  'WeatherData template title' => {
    'lastUpdated' => '1227127140',
    'message' => 'Plantilla para Estado del Tiempo'
  },
  'Your list of default weather locations' => {
    'lastUpdated' => '1227127253',
    'message' => '<p>Lista de localidades cuyo estado del tiempo quiere consultar, una por l&iacute;nea. Puede escribir (las dos primeras solamente son validades dentro de USA):</p><p>Ciudad, ST</p><p>C&oacute;digo Postal USA</p><p>Ciudad, Pa&iacute;s</p>'
  },
  'assetName' => {
    'lastUpdated' => '1227127155',
    'message' => 'Estado del Tiempo'
  },
  'cache timeout help' => {
    'lastUpdated' => '1302873121',
    'message' => '¿Cuánto tiempo almacenar en caché la información obtenida para cada ubicación?'
  },
  'cityState' => {
    'lastUpdated' => '1227127294',
    'message' => 'La ciudad y el estado retornados por NOAA. Probablemente sea id&eacute;ntico a query.'
  },
  'iconUrl' => {
    'lastUpdated' => '1227127319',
    'message' => 'URL a un &iacute;cono que representa la condici&oacute;n del cielo.'
  },
  'licenseKey' => {
    'lastUpdated' => '1227127343',
    'message' => 'Clave de Licencia para Weather.com'
  },
  'licenseKey help' => {
    'lastUpdated' => '1227127398',
    'message' => 'Ingrese la clave recibida por correo electr&oacute;nico despu&eacute;s de registrarse en el Servicio XML de Weather.com para consultar el Estado del Tiempo.'
  },
  'locations' => {
    'lastUpdated' => '1227127423',
    'message' => 'La lista de localidades especificadas por el usuario.'
  },
  'ourLocations.loop' => {
    'lastUpdated' => '1227127473',
    'message' => 'Un bucle que contiene la informaci&oacute;n del Estado del Tiempo de todas las localidades indicadas por el usuario.'
  },
  'partnerId' => {
    'lastUpdated' => '1227127512',
    'message' => 'Partner ID suministrado por Weather.com'
  },
  'partnerId help' => {
    'lastUpdated' => '1227127551',
    'message' => 'Ingrese el Parter ID recibido por correo electr&oacute;nico despu&eacute;s de registrarse en el Servicio XML de Estado del Tiempo de Weather.com.'
  },
  'query' => {
    'lastUpdated' => '1227127575',
    'message' => 'La localidad espec&iacute;fica.'
  },
  'sky' => {
    'lastUpdated' => '1227127603',
    'message' => 'Condici&oacute;n del cielo (soleado, nublado, etc.)'
  },
  'tempF' => {
    'lastUpdated' => '1227127620',
    'message' => 'Temperatura en grados Fahrenheit.'
  },
  'templateId' => {
    'lastUpdated' => '1227127641',
    'message' => 'ID de la Plantilla utilizada para presentar este Activo.'
  },
  'weatherdata asset template variables title' => {
    'lastUpdated' => '1227127661',
    'message' => 'Variables de Plantilla para Estado del Tiempo'
  },
  'you need a weather.com key' => {
    'lastUpdated' => '1227127736',
    'message' => 'Haga click aqu&iacute; para registrarse en el servicio gratuito Weather XML Data Feed the Weather.com, necesario para poder utilizar este activo.'
  }
}
;

1;
